'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

/**
 * String or regexp used to separate sections of movie definition, e.g.
 * default value, scenario and editor options
 */
var SECTION_SEPARATOR = '@@@';

/** Regular expression to extract outline from scenario line */
var OUTLINE_SEPARATOR = /\s+:::\s+(.+)$/;

var COMMAND_REGEX = /^(\w+)\s*:\s*(.+)$/;

var toLines = function toLines(text) {
	// IE fails to split string by regexp, 
	// need to normalize newlines first
	var lines = (text || '').replace(/(\r\n|\n\r|\r)/g, '\n').split('\n');

	return lines.filter(Boolean);
};

var unescape = function unescape(text) {
	var replacements = {
		'&lt;': '<',
		'&gt;': '>',
		'&amp;': '&'
	};

	return text.replace(/&(lt|gt|amp);/g, function (str) {
		return replacements[str] || str;
	});
};

exports.default = function (text) {
	var parts = text.split(SECTION_SEPARATOR);

	var actions = toLines(parts[1]).map(function (line) {
		return line.trim();
	}).filter(function (line) {
		return line && line.charAt(0) !== '#';
	}).map(function (line) {
		return line.replace(OUTLINE_SEPARATOR, '').match(COMMAND_REGEX);
	}).filter(Boolean).map(function (sd) {

		var name = sd[1];
		var actionOptions = unescape(sd[2]);

		if (actionOptions.charAt(0) === '{') {
			actionOptions = JSON.parse(actionOptions);
		}

		return {
			name: name,
			options: actionOptions
		};
	});

	return {
		value: unescape(parts[0].trim()),
		actions: actions
	};
};